diff --git a/src/pkg/unicode/maketables.go b/src/pkg/unicode/maketables.go
index cdc088c06b2c69a8e094c13a1f8851be2b0dc098..cd3f38105a63d1451467497675f954a7bbc1a302 100644
--- a/src/pkg/unicode/maketables.go
+++ b/src/pkg/unicode/maketables.go
@@ -558,7 +558,7 @@ func printScriptOrProperty(doProps bool) {
 		flaglist = *proplist;
 		file = "PropList.txt";
 		table = props;
-		installed = unicode.Props;
+		installed = unicode.Properties;
 	}
 	if flaglist == "" {
 		return
@@ -608,8 +608,8 @@ func printScriptOrProperty(doProps bool) {
 	);
 	if flaglist == "all" {
 		if doProps {
-			fmt.Println("// Props is the set of Unicode property tables.");
-			fmt.Println("var Props = map[string] []Range {");
+			fmt.Println("// Properties is the set of Unicode property tables.");
+			fmt.Println("var Properties = map[string] []Range {");
 		} else {
 			fmt.Println("// Scripts is the set of Unicode script tables.");
 			fmt.Println("var Scripts = map[string] []Range {");
diff --git a/src/pkg/unicode/script_test.go b/src/pkg/unicode/script_test.go
index 6c7934ec8775af80a4a88aff92f0d5d67638421a..613b569ea1f30110a063585574ffe94e3d844347 100644
--- a/src/pkg/unicode/script_test.go
+++ b/src/pkg/unicode/script_test.go
@@ -212,16 +212,16 @@ func TestCategories(t *testing.T) {
 	}
 }
 
-func TestProps(t *testing.T) {
+func TestProperties(t *testing.T) {
 	notTested := make(map[string] bool);
-	for k := range Props {
+	for k := range Properties {
 		notTested[k] = true
 	}
 	for i, test := range inPropTest {
-		if _, ok := Props[test.script]; !ok {
+		if _, ok := Properties[test.script]; !ok {
 			t.Fatal(test.script, "not a known prop")
 		}
-		if !Is(Props[test.script], test.rune) {
+		if !Is(Properties[test.script], test.rune) {
 			t.Errorf("IsCategory(%#x, %s) = false, want true\n", test.rune, test.script);
 		}
 		notTested[test.script] = false, false
diff --git a/src/pkg/unicode/tables.go b/src/pkg/unicode/tables.go
index c5ce78783f564c9dd60e12d09c9fcb3fd6963e8c..d3af40d8de553f074637890feaf2ff8710e7f80b 100644
--- a/src/pkg/unicode/tables.go
+++ b/src/pkg/unicode/tables.go
@@ -2792,8 +2792,8 @@ var (
 //	maketables --props=all --url=http://www.unicode.org/Public/5.1.0/ucd/
 // DO NOT EDIT
 
-// Props is the set of Unicode property tables.
-var Props = map[string] []Range {
+// Properties is the set of Unicode property tables.
+var Properties = map[string] []Range {
 	"Pattern_Syntax": Pattern_Syntax,
 	"Other_ID_Start": Other_ID_Start,
 	"Pattern_White_Space": Pattern_White_Space,